#
# spec file for package eeze
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           eeze
Version:        1.7.4
Release:        11.1
Summary:        Device abstraction library
License:        BSD-2-Clause
Group:          System/Libraries
Url:            http://enlightenment.org
Source:         eeze-%{version}.tar.bz2
BuildRequires:  doxygen
BuildRequires:  ecore-devel >= %version
BuildRequires:  eina-devel >= %version
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRequires:  libtool
%if 0%{?mandriva_version} != 201010 && 0%{?centos_version} != 600 && 0%{?sles_version} != 11
BuildRequires:  libmount-devel
%endif
BuildRequires:  libudev-devel
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Eeze is a library for manipulating devices through udev with a simple
and fast api. It interfaces directly with libudev, avoiding such
middleman daemons as udisks/upower or hal, to immediately gather
device information the instant it becomes known to the system.  This
can be used to determine such things as:
  * If a cdrom has a disk inserted
  * The temperature of a cpu core
  * The remaining power left in a battery
  * The current power consumption of various parts
  * Monitor in realtime the status of peripheral devices

Each of the above examples can be performed by using only a single
eeze function, as one of the primary focuses of the library is to
reduce the complexity of managing devices.

%package -n libeeze1
Summary:        Device abstraction library
Group:          System/Libraries

%description -n libeeze1
Headers, static libraries, test programs and documentation for eeze

%package devel
Summary:        Eeze headers, static libraries, documentation and test programs
Group:          Development/Libraries/C and C++
Requires:       ecore-devel >= %version
Requires:       eina-devel >= %version
Requires:       libeeze1 = %{version}
Requires:       libudev-devel

%description devel
Headers, static libraries, test programs and documentation for eeze

%package doc-html
Summary:        HTML documentation of Eet
Group:          Documentation/HTML

%description doc-html
Documentation of Eet library in form of HTML pages.

%package doc-man
Summary:        Man documentation of Eina
Group:          Documentation/Man

%description doc-man
Documentation of Eina library in form of man pages.

%prep
%setup -q

%build
# fake time used for documentation
FAKE_DOCDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y')
FAKE_DOCYEAR=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%Y')
FAKE_DOCDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y %T')
sed -i "s/\$datetime/$FAKE_DOCDATETIME/g;s/\$date/$FAKE_DOCDATE/g;s/\$year/$FAKEDOCYEAR/g" doc/*.html

%configure --disable-static
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%buildroot" utildir=%{_libdir}/enlightenment/utils

# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}
/bin/cp -vr doc/html %{buildroot}%{_docdir}/%{name}
echo "Copying MAN pages"
/bin/cp -vr doc/man/ %{buildroot}%{_mandir}/
# fix permissions
find %{buildroot}%{_docdir} -type f | xargs chmod 0644
find %{buildroot}%{_docdir} -type d | xargs chmod 0755
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%fdupes -s %{buildroot}%{_mandir}
%endif

find %{buildroot}%{_libdir} -name '*.la' -exec rm -v {} \;

%post -n libeeze1 -p /sbin/ldconfig

%postun -n libeeze1 -p /sbin/ldconfig

%files -n libeeze1
%defattr(-, root, root)
%{_libdir}/libeeze.so.1*

%if 0%{?mandriva_version} != 201010 && 0%{?centos_version} != 600 && 0%{?sles_version} != 11
%files
%defattr(-, root, root)
%{_bindir}/*
%{_libdir}/enlightenment/
%endif

%files devel
%defattr(-, root, root)
%{_includedir}/eeze-1/
%{_libdir}/libeeze.so
%{_libdir}/pkgconfig/eeze.pc

%files doc-html
%defattr(-, root, root)
%{_docdir}/%{name}

%files doc-man
%defattr(-, root, root)
%{_mandir}/*/*

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - 1.7.4-11.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 1.7.4
  Changes since Eeze 1.7.3:
  * Add XML output to doc
  * Add installation rule for doc
* Thu Dec 20 2012 sleep_walker@suse.cz
- package also man pages
* Thu Dec 20 2012 sleep_walker@suse.cz
- build and package documentation
* Sat Dec  8 2012 simon@simotek.net
- Bump to 1.7.3
- 1.7.3 is a bugfix release to coincide with the beta release of efl
* Sat Nov 24 2012 sleep_walker@suse.cz
- require the same version or higher for EFL libraries
* Fri Nov 23 2012 simon@simotek.net
- bump to 1.7.2
  (No real changes - keeping version sync with other EFL libraries)
* Wed Nov 21 2012 sleep_walker@suse.cz
- simplify setup macro
* Wed Nov 21 2012 sleep_walker@suse.cz
- use libmount only for distributions which have it
* Wed Nov 21 2012 sleep_walker@suse.cz
- rework eeze and libeeze1 packages
- move libeeze1.so into devel package
- alter make install phase
- add libmount into dependencies
- build eeze_* binaries again
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove autoreconf as it is not needed for release
* Sun Oct 21 2012 simon@simotek.net
- bump to 1.7.1
* Tue Oct 16 2012 sleep_walker@suse.cz
- fix sles build
* Fri Sep  7 2012 sleep_walker@suse.cz
- revert spec file change makeinstall --> make_install
* Fri Sep  7 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 20e1ef6df5bc33396bbf9f727bf8efcab4200c97
* Thu Sep  6 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 20e1ef6df5bc33396bbf9f727bf8efcab4200c97
* Sun Aug 12 2012 sleep_walker@suse.cz
- alter to 1.7.0-alpha
* Fri Aug 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 2e21a2dabd183782d22b727ea60b9b9815a27403
* Fri Aug 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 39eecec73e0eeda3ad063d79a64c5e2a20419dc4
* Wed Aug  1 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 3b6edf55b8f8f0d9fa1c9396d47a3e15614078ea
* Thu Jul 19 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 6ddeef0d6723d45b5c6c4a480a6467dce6335d31
* Thu Jul 12 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ef3e3c116e5e9e43141bb1aaed5f5bdb310ef845
* Mon Jul  9 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 5a7534c41fd311fa42d02503fc91f08ee3cd0aa0
* Mon Jul  2 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 8bafde7492af888ae7936e9ee82bc13a2e028ea8
* Wed Jun 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 2900e4b20a2090b8fc23d62f7f2bf94dc2bafe2b
* Thu Jun 14 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision aa34d06deb489b0bb38fee6b42720c665c297222
* Mon Jun 11 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 4644861ac1b7240eb1a37c166b8b15b2ac67cdc7
* Tue Jun  5 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 7a59d34f6d79bd45ad3a98874e9e84c7fe0a8007
* Fri Jun  1 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 7f320c1ee4f8896859c5239342053fc74a954185
* Thu May  3 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ef1d2db078f5c350683541c12d63a24688229cb8
* Fri Apr 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision b432496243f303feb9cca834d86ee75801b1538d
* Tue Apr 24 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision f312ed5245cf8f88beb973cee3666889e8f75ffb
* Mon Apr 23 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 29f9b774267b6380aaa78409da6676084d4ea289
* Mon Apr 16 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 1cbfc98d1e991f51a53b57a6d2c0d44063c5583d
* Mon Apr  2 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision cadf4cfb14d65fa1be41d4154b215bdaefa6ff29
* Mon Mar 26 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 90a8391b8be88a617fcefe1e87b1cfb19ca9d1cb
* Fri Jan 20 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision b282c0b4243fe10606b6850cb013d8bf3cbc53cc
* Wed Jan 18 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e347f44069568d6d04265f228c8be544a3e23781
* Tue Jan 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 59b0454c43cc46277c894595ec95060cb2150108
* Fri Dec 30 2011 sleep_walker@suse.cz
- explicitly BuildRequire autoconf, automake and libtool
* Fri Dec 16 2011 sleep_walker@suse.cz
- pre_configure --> pre_configure_hook
* Fri Dec 16 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 57194ce4eb8e0f6920ccd78fb6d36734c262ef8c
* Sun Dec 11 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 90ff3488d8c1dba58b2e8530a816317d4b0480eb
* Tue Nov 15 2011 tcech@suse.com
- bump version to 1.0.999.65256
* Mon Nov 14 2011 tcech@suse.com
- bump version to 1.0.999.65190
* Wed Nov  2 2011 sleep_walker@suse.cz
- libeeze-devel now provides eeze-devel
* Sat Oct 15 2011 tcech@suse.com
- add devel packages required to build as required for devel package
* Thu Oct  6 2011 tcech@suse.com
- fix initialization of utildir variable
* Tue Oct  4 2011 jreidinger@suse.com
- bump version to 1.0.999.63807
* Mon Oct  3 2011 jreidinger@suse.com
- bump version to 1.0.999.63773
* Mon Oct  3 2011 jreidinger@suse.com
- restructure package
* Mon Oct  3 2011 jreidinger@suse.com
- remove disappeared file from section
* Fri Sep 30 2011 jreidinger@suse.com
- bump version to 1.0.999.63723
* Fri Sep 30 2011 jreidinger@suse.com
- bump version
* Fri Sep 30 2011 jreidinger@suse.com
- bump version
* Wed Sep 28 2011 tcech@suse.com
- change pkgconfig dependencies to package names
- add autoreconf call to fix mandriva builds
* Tue Sep 27 2011 jreidinger@suse.com
- update to version 1.0.2
- clean up spec file
* Tue Feb  1 2011 dimstar@opensuse.org
- Initial package, version 1.0.0
